/// <reference types="bn.js" />
import { ConfirmOptions, Connection, PublicKey, Transaction, TransactionInstruction, Signer } from '@solana/web3.js';
import { BN, Idl, Program } from '@project-serum/anchor';
import { Token } from '@solana/spl-token';
export declare const STATE_SEED = "fstate1";
export declare const ACCOUNT_SEED = "faccv1";
export declare const CPI_SEED = "FABRIC";
export declare class Protocol {
    connection: Connection;
    programId: PublicKey;
    adminPubkey: PublicKey;
    assetsListPubkey: PublicKey;
    statePubkey: PublicKey;
    cpiAuthPubkey: PublicKey;
    wallet: IWallet;
    idl: Idl;
    pythIdl: Idl;
    program: Program;
    state: any;
    assetsList: any;
    private constructor();
    static initialise(connection: Connection, wallet: IWallet, programId: PublicKey, opts?: ConfirmOptions): Promise<Protocol>;
    initialiseContract(): Promise<string>;
    initialiseAssetsList(collateralMintPubkey: PublicKey, collateralFeedPubkey: PublicKey, collateralReserveAccountPubkey: PublicKey, collateralLiquidationFundAccountPubkey: PublicKey): Promise<[string, Token, PublicKey]>;
    setAssetsListAccount(assetListPubkey: PublicKey): Promise<string>;
    depositCollateral(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey): Promise<string>;
    depositCollateralIx(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey): Promise<TransactionInstruction>;
    mint(amount: BN, owner: PublicKey, fusdReceiver: PublicKey, userAccount: PublicKey): Promise<string>;
    burn(amount: BN, owner: PublicKey, fusdReceiver: PublicKey, userAccount: PublicKey): Promise<string>;
    withdrawCollateral(amount: BN, userAccount: PublicKey, collateralReserveAccount: PublicKey, userCollateralAccount: PublicKey, owner: PublicKey): Promise<string>;
    swap(amount: BN, owner: PublicKey, tokenAMint: PublicKey, tokenBMint: PublicKey, tokenAReceiver: PublicKey, tokenBReceiver: PublicKey, userAccount: PublicKey): Promise<string>;
    updatePrices(): Promise<string>;
    getStateAccount(): Promise<[PublicKey, number]>;
    getState(): Promise<IState>;
    getAssetList(): Promise<IAssetList>;
    createUserAccount(owner: PublicKey): Promise<PublicKey>;
    getUserAccount(owner: PublicKey): Promise<[PublicKey, number]>;
    getUser(userAccount: PublicKey): Promise<IUser>;
    checkIfUserAccountExists(owner: PublicKey): Promise<boolean>;
    getCpiAuthAccount(): Promise<[PublicKey, number]>;
    mintTokens(amount: number, decimals: number, toAddress: PublicKey, token: Token, authority?: PublicKey, signer?: Signer): Promise<void>;
    createTokenAccount(token: Token, owner: PublicKey): Promise<PublicKey>;
    getAccountBalanceForMint(tokenAccount: PublicKey): Promise<any>;
    getTokenAccountInfo(token: Token, tokenAccount: PublicKey): Promise<import("@solana/spl-token").AccountInfo>;
    getfUsdTokenMint(): Promise<PublicKey>;
    createToken(decimals: number, authority?: PublicKey): Promise<Token>;
    getUserCollateralRatio(userAccount: PublicKey): Promise<number>;
    getUserDebtUsd(userAccount: PublicKey): Promise<number>;
    getUserCollateralUsd(userAccount: PublicKey): Promise<number>;
    getMaximumPossibleUserDebtUsd(userAccount: PublicKey): Promise<number>;
    getGlobalDebtUsd(): Promise<number>;
    getSyntheticSupplyAndMarketCap(mint: PublicKey): Promise<{
        supply: number;
        scaledPrice: number;
        marketCap: number;
    }>;
    getCollateralTvlAndCRatio(mint: PublicKey): Promise<{
        collateralTvl: number;
        collateralRatio: number;
    }>;
}
export interface IWallet {
    signTransaction(tx: Transaction): Promise<Transaction>;
    signAllTransactions(txs: Transaction[]): Promise<Transaction[]>;
    publicKey: PublicKey;
}
export interface IUser {
    owner: PublicKey;
    userDebtShares: BN;
    liquidationDeadline: BN;
    numberOfCollaterals: number;
    bump: number;
    userStakingData: IUserStakingData;
    userCollaterals: Array<IUserCollateral>;
}
export interface IUserCollateral {
    amount: BN;
    collateralMintAddress: PublicKey;
    index: number;
}
export interface IUserStakingData {
    claimableRewards: IDecimal;
    finishedRoundPoints: number;
    currentRoundPoints: number;
    nextRoundPoints: number;
    lastUpdate: number;
}
export interface IAsset {
    priceFeedAddress: PublicKey;
    price: IDecimal;
    lastUpdate: number;
    status: number;
    oracleType: number;
}
export interface IAssetList {
    numberOfAssets: number;
    numberOfCollaterals: number;
    numberOfSynthetics: number;
    assets: Array<IAsset>;
    collaterals: Array<ICollateral>;
    synthetics: Array<ISynthetic>;
}
export interface IState {
    adminPubkey: PublicKey;
    cpiAuthPubkey: PublicKey;
    nonce: number;
    bump: number;
    isHalted: number;
    debtShares: BN;
    liquidationBuffer: BN;
    assetsList: PublicKey;
    delayBuffer: BN;
    protocolSwapFee: IDecimal;
}
export interface ICollateral {
    assetIndex: number;
    collateralMintAddress: PublicKey;
    reserveAddress: PublicKey;
    liquidationFundAddress: PublicKey;
    reserveBalance: IDecimal;
    collateralRatio: IDecimal;
    maximumCollateral: IDecimal;
}
export interface ISynthetic {
    assetIndex: number;
    assetAddress: PublicKey;
    supply: IDecimal;
    maximumSupply: IDecimal;
}
export interface IDecimal {
    val: BN;
    scale: number;
}
